@@ -9,6 +9,7 @@ import warnings
 from pyaedt import _retry_ntimes
 from pyaedt import generate_unique_name
 from pyaedt.edb_core.EDB_Data import EDBComponent
+from pyaedt.edb_core.EDB_Data import EDBComponentDef
 from pyaedt.edb_core.EDB_Data import EDBPadstackInstance
 from pyaedt.edb_core.EDB_Data import Source
 from pyaedt.edb_core.general import convert_py_list_to_net_list
@@ -72,6 +73,7 @@ class Components(object):
     def __init__(self, p_edb):
         self._pedb = p_edb
         self._cmp = {}
+        self._comp_def = {}
         self._res = {}
         self._cap = {}
         self._ind = {}
@@ -147,15 +149,25 @@ class Components(object):
             self.refresh_components()
         return self._cmp
 
+    @property
+    def definitions(self):
+        """Retrieve component definition list.
+
+        Returns
+        -------
+        dict of :class:`pyaedt.edb_core.EDB_Data.EDBComponentDef`"""
+        return {l.GetName(): EDBComponentDef(self, l) for l in list(self._db.ComponentDefs)}
+
     @pyaedt_function_handler()
     def refresh_components(self):
         """Refresh the component dictionary."""
-        self._cmp = {}
         self._logger.info("Refreshing the Components dictionary.")
-        if self._active_layout:
-            for cmp in self._active_layout.Groups:
-                if cmp.GetType().ToString() == "Ansys.Ansoft.Edb.Cell.Hierarchy.Component":
-                    self._cmp[cmp.GetName()] = EDBComponent(self, cmp)
+        self._cmp = {
+            l.GetName(): EDBComponent(self, l)
+            for l in self._active_layout.Groups
+            if l.ToString() == "Ansys.Ansoft.Edb.Cell.Hierarchy.Component"
+        }
+        return True
 
     @property
     def resistors(self):
@@ -961,7 +973,7 @@ class Components(object):
             self._logger.error("Failed to create component definition")
             return False
         new_cmp = self._edb.Cell.Hierarchy.Component.Create(self._active_layout, component_name, comp_def.GetName())
-        hosting_component_location = pins[0].GetComponent().GetLocation()
+        hosting_component_location = pins[0].GetComponent().GetTransform()
         for pin in pins:
             new_cmp.AddMember(pin)
         new_cmp_layer_name = pins[0].GetPadstackDef().GetData().GetLayerNames()[0]
@@ -1003,7 +1015,7 @@ class Components(object):
             edb_rlc_component_property
         ):
             return False  # pragma no cover
-        new_cmp.SetLocation(hosting_component_location[1], hosting_component_location[2])
+        new_cmp.SetTransform(hosting_component_location)
         return new_cmp
 
     @pyaedt_function_handler()
@@ -1295,7 +1307,13 @@ class Components(object):
 
     @pyaedt_function_handler()
     def set_solder_ball(
-        self, component="", sball_diam="100um", sball_height="150um", shape="Cylinder", sball_mid_diam=None
+        self,
+        component="",
+        sball_diam="100um",
+        sball_height="150um",
+        shape="Cylinder",
+        sball_mid_diam=None,
+        chip_orientation="chip_down",
     ):
         """Set cylindrical solder balls on a given component.
 
@@ -1312,6 +1330,9 @@ class Components(object):
             ``"Spheroid"``. The default is ``"Cylinder"``.
         sball_mid_diam : str, float, optional
             Mid diameter of the solder ball.
+        chip_orientation : str
+            Give the chip orientation, ``"chip_down"`` or ``"chip_up"``. Default is ``"chip_down"``. Only applicable on
+            IC model.
         Returns
         -------
         bool
@@ -1353,7 +1374,12 @@ class Components(object):
             if cmp_type == self._edb.Definition.ComponentType.IC:
                 ic_die_prop = cmp_property.GetDieProperty().Clone()
                 ic_die_prop.SetType(self._edb.Definition.DieType.FlipChip)
-                ic_die_prop.SetOrientation(self._edb.Definition.DieOrientation.ChipDown)
+                if chip_orientation.lower() == "chip_down":
+                    ic_die_prop.SetOrientation(self._edb.Definition.DieOrientation.ChipDown)
+                if chip_orientation.lower() == "chip_up":
+                    ic_die_prop.SetOrientation(self._edb.Definition.DieOrientation.ChipUp)
+                else:
+                    ic_die_prop.SetOrientation(self._edb.Definition.DieOrientation.ChipDown)
                 cmp_property.SetDieProperty(ic_die_prop)
 
             solder_ball_prop = cmp_property.GetSolderBallProperty().Clone()
@@ -1522,6 +1548,124 @@ class Components(object):
                 self.components[comp].is_enabled = False
         return found
 
+    @pyaedt_function_handler()
+    def import_bom(
+        self,
+        bom_file,
+        delimiter=",",
+        refdes_col=0,
+        part_name_col=1,
+        comp_type_col=2,
+        value_col=3,
+    ):
+        """Load external BOM file.
+
+        Parameters
+        ----------
+        bom_file : str
+            Full path to the BOM file, which is a delimited text file.
+        delimiter : str, optional
+            Value to use for the delimiter. The default is ``","``.
+        refdes_col : int, optional
+            Column index of reference designator. The default is ``"0"``.
+        part_name_col : int, optional
+             Column index of part name. The default is ``"1"``. Set to ``None`` if
+             the column does not exist.
+        comp_type_col : int, optional
+            Column index of component type. The default is ``"2"``.
+        value_col : int, optional
+            Column index of value. The default is ``"3"``. Set to ``None``
+            if the column does not exist.
+        Returns
+        -------
+        bool
+        """
+        with open(bom_file, "r") as f:
+            lines = f.readlines()
+            unmount_comp_list = list(self.components.keys())
+            for l in lines[1:]:
+                l = l.replace(" ", "").replace("\n", "")
+                if not l:
+                    continue
+                l = l.split(delimiter)
+
+                refdes = l[refdes_col]
+                comp = self.components[refdes]
+                if not part_name_col == None:
+                    part_name = l[part_name_col]
+                    if comp.partname == part_name:
+                        pass
+                    else:
+                        pinlist = self.get_pin_from_component(refdes)
+                        if not part_name in self.definitions:
+                            footprint_cell = self.definitions[comp.partname]._edb_comp_def.GetFootprintCell()
+                            comp_def = self._edb.Definition.ComponentDef.Create(self._db, part_name, footprint_cell)
+                            for pin in pinlist:
+                                self._edb.Definition.ComponentDefPin.Create(comp_def, pin.GetName())
+
+                        p_layer = comp.placement_layer
+                        refdes_temp = comp.refdes + "_temp"
+                        comp.refdes = refdes_temp
+
+                        unmount_comp_list.remove(refdes)
+                        comp.edbcomponent.Ungroup(True)
+
+                        self.create_component_from_pins(pinlist, refdes, p_layer, part_name)
+                        self.refresh_components()
+                        comp = self.components[refdes]
+
+                comp_type = l[comp_type_col].upper()
+                comp.type = comp_type
+                print(comp.refdes, comp_type)
+                if comp_type in ["RESISTOR", "CAPACITOR", "INDUCTOR"]:
+                    unmount_comp_list.remove(refdes)
+                if not value_col == None:
+                    try:
+                        value = l[value_col]
+                    except:
+                        value = None
+                    if value:
+                        if comp_type == "RESISTOR":
+                            self.set_component_rlc(refdes, res_value=value)
+                        elif comp_type == "CAPACITOR":
+                            self.set_component_rlc(refdes, cap_value=value)
+                        elif comp_type == "INDUCTOR":
+                            self.set_component_rlc(refdes, ind_value=value)
+            for comp in unmount_comp_list:
+                self.components[comp].is_enabled = False
+        return True
+
+    @pyaedt_function_handler()
+    def export_bom(self, bom_file, delimiter=","):
+        """Export Bom file from layout.
+
+        Parameters
+        ----------
+        bom_file : str
+            Full path to the BOM file, which is a delimited text file.
+        delimiter : str, optional
+            Value to use for the delimiter. The default is ``","``.
+        """
+        with open(bom_file, "w") as f:
+            f.writelines([delimiter.join(["RefDes", "Part name", "Type", "Value\n"])])
+            for refdes, comp in self.components.items():
+                if not comp.is_enabled and comp.type in ["RESISTOR", "CAPACITOR", "INDUCTOR"]:
+                    continue
+                part_name = comp.partname
+                comp_type = comp.type
+                if comp_type == "RESISTOR":
+                    value = comp.res_value
+                elif comp_type == "CAPACITOR":
+                    value = comp.cap_value
+                elif comp_type == "INDUCTOR":
+                    value = comp.ind_value
+                else:
+                    value = ""
+                if not value:
+                    value = ""
+                f.writelines([delimiter.join([refdes, part_name, comp_type, value + "\n"])])
+        return True
+
     @pyaedt_function_handler()
     def get_pin_from_component(self, component, netName=None, pinName=None):
         """Retrieve the pins of a component.
