@@ -52,11 +52,6 @@ class EdbNets(object):
         """Db object."""
         return self._pedb.db
 
-    @property
-    def _padstack_methods(self):
-        """ """
-        return self._pedb.edblib.Layout.PadStackMethods
-
     @property
     def _logger(self):
         """Edb logger."""
