@@ -123,6 +123,16 @@ class Materials(object):
             self._mats_lower = [i.lower() for i in self._mat_names_aedt]
         return self._mats_lower
 
+    @property
+    def mat_names_aedt(self):
+        """List material names."""
+        return self._mat_names_aedt
+
+    @property
+    def mat_names_aedt_lower(self):
+        """List material names with lower case."""
+        return self._mat_names_aedt_lower
+
     @pyaedt_function_handler()
     def _read_materials(self):
         def get_mat_list(file_name):
@@ -175,8 +185,8 @@ class Materials(object):
     def _get_aedt_case_name(self, material_name):
         if material_name.lower() in self.material_keys:
             return self.material_keys[material_name.lower()].name
-        if material_name.lower() in self._mat_names_aedt_lower:
-            return self._mat_names_aedt[self._mat_names_aedt_lower.index(material_name.lower())]
+        if material_name.lower() in self.mat_names_aedt_lower:
+            return self._mat_names_aedt[self.mat_names_aedt_lower.index(material_name.lower())]
         return False
 
     @pyaedt_function_handler()
@@ -233,12 +243,12 @@ class Materials(object):
             else:
                 return False
         if mat.lower() in self.material_keys:
-            if mat.lower() in self._mat_names_aedt_lower:
+            if mat.lower() in self.mat_names_aedt_lower:
                 return self.material_keys[mat.lower()]
             if mat.lower() not in list(self.odefinition_manager.GetProjectMaterialNames()):
                 self.material_keys[mat.lower()].update()
             return self.material_keys[mat.lower()]
-        elif mat.lower() in self._mat_names_aedt_lower:
+        elif mat.lower() in self.mat_names_aedt_lower:
             return self._aedmattolibrary(mat)
         elif settings.remote_api:
             return self._aedmattolibrary(mat)
